@@ -1,6 +1,6 @@
 
 package Importer::Zim::EndOfScope;
-$Importer::Zim::EndOfScope::VERSION = '0.2.0';
+$Importer::Zim::EndOfScope::VERSION = '0.3.0';
 # ABSTRACT: Import functions with compilation block scope
 
 use 5.010001;
@@ -23,8 +23,19 @@ sub import {
     my @exports = $class->_prepare_args(@_);
 
     my $caller = caller;
-    my $old    = Sub::Replace::sub_replace(
-        map { ; "${caller}::$_->{export}" => $_->{code} } @exports );
+    return _export_to( map { ; "${caller}::$_->{export}" => $_->{code} }
+          @exports );
+}
+
+sub export_to {
+    my $t = shift;
+    @_ = %{ $_[0] } if @_ == 1 && ref $_[0] eq 'HASH';
+    @_ = map { $_ & 1 ? $_[$_] : "${t}::$_[$_]" } 0 .. $#_;
+    goto &_export_to;
+}
+
+sub _export_to {
+    my $old = Sub::Replace::sub_replace(@_);
 
     # Clean it up after a scope finished compilation
     B::Hooks::EndOfScope::on_scope_end(
@@ -138,7 +149,7 @@ Importer::Zim::EndOfScope - Import functions with compilation block scope
 
 =head1 VERSION
 
-version 0.2.0
+version 0.3.0
 
 =head1 SYNOPSIS
 
